# Generated by Django 2.0.5 on 2018-05-09 12:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_textract', '0001_squashed_0004_auto_20180508_0942'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='document',
            options={},
        ),
    ]
